@@ -178,9 +178,7 @@ def render_circle(jinja_env, forge_config, forge_dir):
             forge_config['upload_script'] = "upload_or_check_non_existence"
 
         # TODO: Conda has a convenience for accessing nested yaml content.
-        templates = forge_config.get('templates', {})
-        template_name = templates.get('run_docker_build',
-                                      'run_docker_build_matrix.tmpl')
+        template_name = 'run_docker_build.tmpl'
         template = jinja_env.get_template(template_name)
         target_fname = os.path.join(forge_dir, 'ci_support', 'run_docker_build.sh')
         with write_file(target_fname) as fh:
@@ -201,7 +199,7 @@ def render_circle(jinja_env, forge_config, forge_dir):
         for each_target_fname in target_fnames:
             set_exe_file(each_target_fname, True)
 
-    target_fname = os.path.join(forge_dir, 'circle.yml')
+    target_fname = os.path.join(forge_dir, '.circleci', 'config.yml')
     template = jinja_env.get_template('circle.yml.tmpl')
     with write_file(target_fname) as fh:
         fh.write(template.render(**forge_config))
@@ -650,7 +648,7 @@ def main(forge_file_directory):
     config = {'docker': {'executable': 'docker',
                          'image': 'condaforge/linux-anvil',
                          'command': 'bash'},
-              'templates': {'run_docker_build': 'run_docker_build_matrix.tmpl'},
+              'templates': {},
               'travis': {},
               'circle': {},
               'appveyor': {},
@@ -665,6 +663,7 @@ def main(forge_file_directory):
     old_files = [
         'disabled_appveyor.yml',
         os.path.join('ci_support', 'upload_or_check_non_existence.py'),
+        'circle.yml',
     ]
     for old_file in old_files:
         remove_file(os.path.join(forge_dir, old_file))
@@ -701,7 +700,8 @@ def main(forge_file_directory):
 
     tmplt_dir = os.path.join(conda_forge_content, 'templates')
     # Load templates from the feedstock in preference to the smithy's templates.
-    env = Environment(loader=FileSystemLoader([os.path.join(forge_dir, 'templates'),
+    env = Environment(extensions=['jinja2.ext.do'],
+                      loader=FileSystemLoader([os.path.join(forge_dir, 'templates'),
                                                tmplt_dir]))
 
     copy_feedstock_content(forge_dir)
